# Table of Contents

- [conceptual-data-layer-mapping-from-collibra-to-sap-leanix](<./conceptual-data-layer-mapping-from-collibra-to-sap-leanix.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Conceptual Data Layer Mapping from Collibra to SAP LeanIX](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX.md>)
  - [Introduction](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX/Introduction.md>)
  - [Configuring Synchronization of Conceptual Data Layer](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX/Configuring-Synchronization-of-Conceptual-Data-Layer.md>)
  - [Choosing the Source Communities](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX/Choosing-the-Source-Communities.md>)
  - [Matching Strategy](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX/Matching-Strategy.md>)
  - [Hierarchy and Naming](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX/Hierarchy-and-Naming.md>)
  - [Subtype of the Data Object](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX/Subtype-of-the-Data-Object.md>)
  - [Filtering Assets by Type and Status](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX/Filtering-Assets-by-Type-and-Status.md>)
  - [Mapping Fields](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX/Mapping-Fields.md>)
  - [Mapping Responsibilities to Subscriptions](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX/Mapping-Responsibilities-to-Subscriptions.md>)
  - [Mapping Relations Between the Assets](<./Conceptual-Data-Layer-Mapping-from-Collibra-to-SAP-LeanIX/Mapping-Relations-Between-the-Assets.md>)
